package com.agilecontrol.nea.core.util;

import com.agilecontrol.nea.util.NDSRuntimeException;
import com.agilecontrol.nea.util.Tools;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;
import org.apache.commons.lang.SystemUtils;

public class MacAddress {

   private static Pattern macPattern = Pattern.compile("[0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0 -9a-fA-F]{2}[-:][0-9a-fA-F]{2}");


   private static List getWindowsMACAddresses() {
      try {
         Process conf = Runtime.getRuntime().exec("ipconfig /all");
         BufferedReader input = new BufferedReader(new InputStreamReader(conf.getInputStream()));
         return getMACAddresses(input);
      } catch (Exception var2) {
         return new ArrayList(1);
      }
   }

   private static List getLinuxMACAddresses() {
      try {
         Process conf = Runtime.getRuntime().exec("/sbin/ifconfig");
         BufferedReader input = new BufferedReader(new InputStreamReader(conf.getInputStream()));
         return getMACAddresses(input);
      } catch (Exception var2) {
         return new ArrayList(1);
      }
   }

   private static List getHPUXMACAddresses() {
      try {
         Process conf = Runtime.getRuntime().exec("/etc/lanscan");
         BufferedReader input = new BufferedReader(new InputStreamReader(conf.getInputStream()));
         return getMACAddresses(input);
      } catch (Exception var2) {
         return new ArrayList(1);
      }
   }

   private static List getSolarisMACAddresses() {
      try {
         ArrayList rtc = new ArrayList(1);
         Process conf = Runtime.getRuntime().exec("/usr/sbin/arp " + InetAddress.getLocalHost().getHostAddress());
         BufferedReader input = new BufferedReader(new InputStreamReader(conf.getInputStream()));
         rtc.addAll(getMACAddresses(input));
         input.close();
         input = null;
         conf = null;
         macPattern = Pattern.compile("[0-9a-fA-F][-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0 -9a-fA-F]{2}[-:][0-9a-fA-F]{2}");
         conf = Runtime.getRuntime().exec("/usr/sbin/arp " + InetAddress.getLocalHost().getHostAddress());
         input = new BufferedReader(new InputStreamReader(conf.getInputStream()));
         rtc.addAll(getMACAddresses(input));
         ArrayList var4 = rtc;
         return var4;
      } catch (Exception var8) {
         ;
      } finally {
         macPattern = Pattern.compile("[0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0 -9a-fA-F]{2}[-:][0-9a-fA-F]{2}");
      }

      return new ArrayList(1);
   }

   private static List getMACAddresses(BufferedReader input) throws Exception {
      ArrayList MACs = new ArrayList(1);

      String theLine;
      while((theLine = input.readLine()) != null) {
         String[] ss = macPattern.split(theLine);

         for(int p = 0; p < ss.length; ++p) {
            String s = theLine.substring(theLine.indexOf(ss[p]) + ss[p].length()).trim();
            if(!s.equals("")) {
               String s1 = s.replaceAll("-", ":");
               String s2 = s1.substring(0, s1.lastIndexOf(":") + 3);
               if(s2.length() == 16 || s2.length() == 17) {
                  MACs.add(s2);
               }
            }
         }
      }

      return MACs;
   }

   public static List getAllMACAddresses() {
      ArrayList MACS = new ArrayList();
      if(SystemUtils.IS_OS_WINDOWS) {
         MACS.addAll(getWindowsMACAddresses());
      } else if(SystemUtils.IS_OS_LINUX) {
         MACS.addAll(getLinuxMACAddresses());
      } else if(SystemUtils.IS_OS_SOLARIS) {
         MACS.addAll(getSolarisMACAddresses());
      } else {
         if(!SystemUtils.IS_OS_HP_UX) {
            throw new NDSRuntimeException("Unsupported Operating System:" + System.getProperty("os.name"));
         }

         MACS.addAll(getHPUXMACAddresses());
      }

      return MACS;
   }

   public static void main(String[] args) throws Exception {
      System.out.println(Tools.toString(getAllMACAddresses(), ","));
   }

}
